@@ -719,13 +719,13 @@ def _list_keys(context, key_prefix, delimiter):
     @gen.coroutine
     def _list_first_page():
         response = yield _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys)
-        print(json.dumps(response))
+        print(response)
         return _parse_list_response(response)
 
     @gen.coroutine
     def _list_later_page(token):
         response = yield _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys, token)
-        print(json.dumps(response))
+        print(response)
 
         return _parse_list_response(response)
 
